class Autobrr < Formula
  desc "Modern, easy to use download automation for torrents and usenet"
  homepage "https://autobrr.com/"
  url "https://github.com/autobrr/autobrr/archive/refs/tags/v1.41.0.tar.gz"
  sha256 "096159986b73cc5f2550f61e94f6a7d7314718c0545642c2034836005648c258"
  license "GPL-2.0-or-later"

  depends_on "go" => :build
  depends_on "node" => :build
  depends_on "pnpm" => :build

  # Update pnpm and dependency lockfile
  # upstream PR patch, https://github.com/autobrr/autobrr/pull/1515
  patch do
    url "https://raw.githubusercontent.com/Homebrew/formula-patches/9ac9588f76a579c2cceac9d7665031d0766268c6/autobrr/autobrr-1.41.0-pnpm.patch"
    sha256 "08d07758290377ad76f11bcff33a84c6e33d188554801039e647c142905802d3"
  end

  def install
    system "pnpm", "install", "--dir", "web"
    system "pnpm", "--dir", "web", "run", "build"

    ldflags = "-s -w -X main.version=#{version} -X main.commit=#{tap.user}"

    system "go", "build", *std_go_args(output: bin/"autobrr", ldflags:), "./cmd/autobrr"
    system "go", "build", *std_go_args(output: bin/"autobrrctl", ldflags:), "./cmd/autobrrctl"
  end

  def post_install
    (var/"autobrr").mkpath
  end

  service do
    run [opt_bin/"autobrr", "--config", var/"autobrr/"]
    keep_alive true
    log_path var/"log/autobrr.log"
  end

  test do
    assert_match version.to_s, shell_output("#{bin}/autobrrctl version")

    port = free_port

    (testpath/"config.toml").write <<~EOS
      host = "127.0.0.1"
      port = #{port}
      logLevel = "INFO"
      checkForUpdates = false
      sessionSecret = "secret-session-key"
    EOS

    pid = fork do
      exec "#{bin}/autobrr", "--config", "#{testpath}/"
    end
    sleep 4

    begin
      system "curl", "-s", "--fail", "http://127.0.0.1:#{port}/api/healthz/liveness"
    ensure
      Process.kill("TERM", pid)
      Process.wait(pid)
    end
  end
end
